use eframe::{
    egui::{self, RichText, Window},
    epaint::Color32,
};
use itertools::Itertools;

use crate::AppState;

pub struct RollViewWindow {
    roll: usize,
    confirm_delete: bool,
    exp: u8,
}

impl RollViewWindow {
    pub fn new(roll: usize) -> Self {
        Self {
            roll,
            confirm_delete: false,
            exp: 0,
        }
    }

    pub fn draw(&mut self, ctx: &egui::Context, app_state: &mut AppState) -> bool {
        let mut close_unclicked = true;
        let mut close_window = false;
        let window = Window::new(format!("Roll {}", app_state.rolls[self.roll].id))
            .open(&mut close_unclicked);
        window.show(ctx, |ui| {
            let roll = &mut app_state.rolls[self.roll];
            ui.label(format!("Name: {}", roll.name));
            ui.label(format!("Description: {}", roll.desc));
            ui.label(format!("Date: {}", roll.date.format("%Y-%m-%d")));
            ui.label("Exposures:");
            ui.horizontal_top(|ui| {
                ui.vertical(|ui| {
                    for (i, chunk) in roll.exposures.iter().chunks(5).into_iter().enumerate() {
                        ui.horizontal(|ui| {
                            for (j, exp) in chunk.enumerate() {
                                let num = i * 5 + j;
                                let mut label = RichText::new(format!("{:02}", exp.num));
                                if exp.printed {
                                    if exp.damaged {
                                        label = label.color(Color32::DARK_RED);
                                    } else {
                                        label = label.color(Color32::DARK_BLUE);
                                    }
                                }
                                ui.selectable_value(&mut self.exp, num as u8, label);
                            }
                        });
                    }
                });
                ui.vertical(|ui| {
                    let exp = &mut roll.exposures[self.exp as usize];
                    ui.checkbox(&mut exp.printed, "Printed");
                    if !exp.printed {
                        exp.damaged = false;
                    }
                    if exp.printed {
                        ui.checkbox(&mut exp.damaged, "Damaged");
                    }
                });
            });
            if ui.button("Delete").clicked() {
                self.confirm_delete = true;
            }
            if self.confirm_delete {
                Window::new("Confirm delete").show(ctx, |ui| {
                    ui.heading(format!(
                        "Really delete roll {}?",
                        app_state.rolls[self.roll].id
                    ));
                    if ui.button("No").clicked() {
                        self.confirm_delete = false;
                    }
                    if ui.button("Yes").clicked() {
                        app_state.rolls.remove(self.roll);
                        close_window = true;
                    }
                });
            }
        });
        !close_unclicked || close_window
    }

    pub fn roll(&self) -> usize {
        self.roll
    }
}
